@@ -5,7 +5,7 @@ use JSON qw/decode_json to_json/;
 use Sub::Data::Recursive;
 use Getopt::Long qw/GetOptionsFromArray/;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 my $MAX_DEPTH = 10;
 
@@ -43,12 +43,31 @@ sub process {
         return $line;
     }
     else {
+        $self->_recursive_split($decoded) if $self->opt('x');
         $self->{_depth} = $self->opt('depth');
         $self->_recursive_decode_json($decoded);
         return to_json($decoded, {pretty => !$self->opt('no_pretty')});
     }
 }
 
+sub _recursive_split {
+    my ($self, $hash) = @_;
+
+    Sub::Data::Recursive->invoke(
+        sub {
+            my $line = $_[0];
+
+            chomp $line;
+
+            if ($line =~ m![\t\r\n]!) {
+                my @elements = split /[\t\r\n]/, $line;
+                $_[0] = \@elements;
+            }
+        },
+        $hash
+    );
+}
+
 sub _recursive_decode_json {
     my ($self, $hash) = @_;
 
@@ -81,6 +100,7 @@ sub _parse_opt {
         \@argv,
         'depth=s'   => \$opt->{depth},
         'no-pretty' => \$opt->{no_pretty},
+        'x'         => \$opt->{x},
         'h|help'    => sub {
             $class->_show_usage(1);
         },
@@ -148,7 +168,7 @@ The parser of the line
 
 =begin html
 
-<a href="http://travis-ci.org/bayashi/App-jl"><img src="https://secure.travis-ci.org/bayashi/App-jl.png?_t=1557029628"/></a> <a href="https://coveralls.io/r/bayashi/App-jl"><img src="https://coveralls.io/repos/bayashi/App-jl/badge.png?_t=1557029628&branch=master"/></a>
+<a href="http://travis-ci.org/bayashi/App-jl"><img src="https://secure.travis-ci.org/bayashi/App-jl.png?_t=1557473289"/></a> <a href="https://coveralls.io/r/bayashi/App-jl"><img src="https://coveralls.io/repos/bayashi/App-jl/badge.png?_t=1557473289&branch=master"/></a>
 
 =end html
 
